<?php
/**
 * 礼品码管理类
 * 处理礼品码生成和使用
 */

class GiftCodeManager {
    private $db;
    
    /**
     * 构造函数
     * 
     * @param DatabaseManager $db 数据库管理器
     */
    public function __construct($db) {
        $this->db = $db;
    }
    
    /**
     * 生成礼品码
     * 
     * @param int $telegramId 用户Telegram ID
     * @param int $months 月数
     * @return string 礼品码
     */
    public function generateCode($telegramId, $months) {
        // 生成唯一礼品码
        $code = 'TGPREMIUM-' . strtoupper(substr(md5($telegramId . time() . rand(1000, 9999)), 0, 10));
        
        // 保存礼品码到数据库
        $this->db->insert('gift_codes', [
            'code' => $code,
            'telegram_id' => $telegramId,
            'duration' => $months,
            'status' => 'active',
            'created_at' => date('Y-m-d H:i:s')
        ]);
        
        return $code;
    }
    
    /**
     * 验证礼品码
     * 
     * @param string $code 礼品码
     * @return array|false 礼品码信息或失败
     */
    public function verifyCode($code) {
        return $this->db->getRow(
            "SELECT * FROM gift_codes WHERE code = ? AND status = 'active'",
            [$code]
        );
    }
    
    /**
     * 使用礼品码
     * 
     * @param string $code 礼品码
     * @param int $telegramId 使用者Telegram ID
     * @return bool 是否使用成功
     */
    public function useCode($code, $telegramId) {
        // 验证礼品码
        $giftCode = $this->verifyCode($code);
        
        if (!$giftCode) {
            return false;
        }
        
        // 更新礼品码状态
        $result = $this->db->update('gift_codes', 
            [
                'status' => 'used',
                'used_by' => $telegramId,
                'used_at' => date('Y-m-d H:i:s')
            ],
            'id = ?',
            [$giftCode['id']]
        );
        
        return $result !== false;
    }
    
    /**
     * 获取用户的礼品码
     * 
     * @param int $telegramId 用户Telegram ID
     * @return array 礼品码列表
     */
    public function getUserCodes($telegramId) {
        return $this->db->getRows(
            "SELECT * FROM gift_codes WHERE telegram_id = ? ORDER BY created_at DESC",
            [$telegramId]
        );
    }
}
