<?php
/**
 * Telegram会员充值机器人主入口
 * 处理Webhook请求和用户交互
 */
// 在bot.php文件开头添加
file_put_contents(__DIR__ . '/callback_debug.log', date('Y-m-d H:i:s') . ' - 脚本开始执行' . "\n", FILE_APPEND);

// 引入配置文件和类
require_once __DIR__ . '/config.php';
require_once __DIR__ . '/DatabaseManager.php';
require_once __DIR__ . '/TelegramBot.php';
require_once __DIR__ . '/PaymentManager.php';
require_once __DIR__ . '/TransactionVerifier.php';
require_once __DIR__ . '/PremiumActivator.php';
require_once __DIR__ . '/TelegramMenuHandler.php';
require_once __DIR__ . '/MembershipCallbacks.php';

// 设置Webhook
if (isset($_GET['setwebhook'])) {
    $webhookUrl = 'https://' . $_SERVER['HTTP_HOST'] . $_SERVER['PHP_SELF'];
    $result = file_get_contents("https://api.telegram.org/bot" . BOT_TOKEN . "/setWebhook?url=" . $webhookUrl);
    echo $result;
    exit;
}

// 初始化数据库连接
$db = new DatabaseManager();

// 初始化Telegram机器人
$bot = new TelegramBot(BOT_TOKEN);

// 创建菜单处理器实例
$menuHandler = new TelegramMenuHandler(BOT_TOKEN, $db);

// 记录日志
if (function_exists('logMessage')) {
    logMessage("收到Webhook请求: " . file_get_contents('php://input'));
}

// 获取更新数据
$update = json_decode(file_get_contents('php://input'), true);

// 处理消息
if (isset($update['message'])) {
    $message = $update['message'];
    $chatId = $message['chat']['id'];
    $text = $message['text'] ?? '';
    $username = $message['from']['username'] ?? '';
    $firstName = $message['from']['first_name'] ?? '';
    $lastName = $message['from']['last_name'] ?? '';
    
    // 获取用户ID
    $user = $db->getRow("SELECT * FROM users WHERE telegram_id = ?", [$chatId]);
    $userId = $user ? $user['id'] : null;
    
    // 如果用户不存在，创建用户
    if (!$userId) {
        $db->insert('users', [
            'telegram_id' => $chatId,
            'username' => $username,
            'first_name' => $firstName,
            'last_name' => $lastName,
            'created_at' => date('Y-m-d H:i:s')
        ]);
        
        $user = $db->getRow("SELECT * FROM users WHERE telegram_id = ?", [$chatId]);
        $userId = $user ? $user['id'] : null;
    }
    
    // 获取用户状态
    $userState = getUserState($chatId, $db);
    
    // 处理等待输入用户名状态
    if ($userState['state'] === 'waiting_gift_username') {
        // 检查输入是否为用户名
        if (strpos($text, '@') === 0) {
            // 保存目标用户名
            $targetUsername = substr($text, 1); // 去掉@
            
            // 更新用户状态
            saveUserState($chatId, 'selecting_gift_plan', ['gift_username' => $targetUsername], $db);
            
            // 获取会员套餐列表并显示
            $plans = $db->getRows("SELECT * FROM membership_plans ORDER BY duration_days ASC");
            
            if (empty($plans)) {
                $bot->sendMessage($chatId, "暂无可用的会员套餐，请稍后再试。");
                return;
            }
            
            // 构建消息
            $message = "<b>请选择要赠送的会员套餐</b>\n\n";
            $message .= "赠送给: @{$targetUsername}\n\n";
            
            foreach ($plans as $plan) {
                $message .= "{$plan['name']} / {$plan['price_usdt']} U\n";
            }
            
            // 构建按钮
            $buttons = [];
            
            foreach ($plans as $plan) {
                $buttons[] = [
                    ['text' => "{$plan['name']} / {$plan['price_usdt']} U", 'callback_data' => "gift_plan_{$plan['plan_id']}"]
                ];
            }
            
            $buttons[] = [
                ['text' => '关闭', 'callback_data' => "close"]
            ];
            
            $keyboard = $bot->createInlineKeyboard($buttons);
            $bot->sendMessage($chatId, $message, $keyboard);
        } else {
            $bot->sendMessage($chatId, "请输入有效的用户名，以@开头，如 @ys_maidong");
        }
        
        return;
    }
    
    // 处理命令
    if ($text === '/start') {
        $menuHandler->handleStart($chatId, $username, $firstName, $lastName);
        return;
    }
    
    // 处理主菜单按钮点击
    $menuHandler->handleMainMenuClick($chatId, $text);
    
    return;
} else if (isset($update['callback_query'])) {
    $callbackQuery = $update['callback_query'];
    $callbackId = $callbackQuery['id'];
    $chatId = $callbackQuery['message']['chat']['id'];
    $callbackData = $callbackQuery['data'];
    
    // 获取用户ID
    $user = $db->getRow("SELECT * FROM users WHERE telegram_id = ?", [$chatId]);
    $userId = $user ? $user['id'] : null;
    
    if (!$userId) {
        $bot->answerCallbackQuery($callbackId, "用户信息不存在，请重新开始", true);
        exit;
    }
    
    // 获取用户状态
    $userState = getUserState($chatId, $db);
    
    // 处理赠送会员套餐选择
    if (strpos($callbackData, 'gift_plan_') === 0 && $userState['state'] === 'selecting_gift_plan') {
        $planId = substr($callbackData, 10);
        
        // 获取会员套餐信息
        $plan = $db->getRow("SELECT * FROM membership_plans WHERE plan_id = ?", [$planId]);
        
        if (!$plan) {
            $bot->answerCallbackQuery($callbackId, "会员套餐不存在", true);
            exit;
        }
        
        // 获取目标用户名
        $giftUsername = $userState['data']['gift_username'] ?? '';
        
        if (empty($giftUsername)) {
            $bot->answerCallbackQuery($callbackId, "目标用户名获取失败，请重新开始", true);
            exit;
        }
        
        // 处理赠送会员
        handleGiftMembership($chatId, $userId, $user['balance'], $plan, $giftUsername, $db, $bot);
        
        // 重置用户状态
        saveUserState($chatId, 'none', [], $db);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理会员选择
    if ($callbackData === 'membership') {
        showMembershipPlans($chatId, $userId, $db, $bot);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理充值选择
    if ($callbackData === 'recharge') {
        showRechargeOptions($chatId, $userId, $db, $bot);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理充值金额选择
    if (strpos($callbackData, 'recharge_amount_') === 0) {
        $amount = substr($callbackData, 16);
        handleRecharge($chatId, $userId, $amount, $db, $bot);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理赠送他人会员
    if ($callbackData === 'membership_gift') {
        // 提示用户输入要赠送的用户名
        $message = "请输入您要赠送会员的用户名\n\n用户名以 @ 开头，如 @ys_maidong\n请发送你需要开通 / 续费会员的Telegram用户名。";
        $bot->sendMessage($chatId, $message);
        
        // 更新用户状态为等待输入用户名
        saveUserState($chatId, 'waiting_gift_username', [], $db);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理关闭按钮
    if ($callbackData === 'close') {
        // 删除当前消息
        $messageId = $callbackQuery['message']['message_id'];
        $bot->deleteMessage($chatId, $messageId);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理关闭充值
    if ($callbackData === 'close_recharge') {
        // 删除当前消息
        $messageId = $callbackQuery['message']['message_id'];
        $bot->deleteMessage($chatId, $messageId);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理客服
    if ($callbackData === 'customer_service') {
        $message = "如有疑问请联系客服 @ys_maidong";
        $bot->sendMessage($chatId, $message);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理我的订单
    if ($callbackData === 'my_orders') {
        showMyOrders($chatId, $userId, $db, $bot);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理个人中心
    if ($callbackData === 'profile') {
        showUserProfile($chatId, $userId, $db, $bot);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理其他业务
    if ($callbackData === 'other_services') {
        $message = "机器人开发【监听机器人,双向机器人,群发机器人,记账机器人,会员机器人,定制机器人等】";
        $bot->sendMessage($chatId, $message);
        $bot->answerCallbackQuery($callbackId);
        exit;
    }
    
    // 处理会员购买相关回调
    handleMembershipCallback($chatId, $userId, $callbackData, $db, $bot);
    $bot->answerCallbackQuery($callbackId);
    exit;
} else {
    if (function_exists('logMessage')) {
        logMessage("未知的更新类型", "WARNING");
    }
}

/**
 * 获取用户状态
 * 
 * @param int $chatId 聊天ID
 * @param object $db 数据库对象
 * @return array 用户状态
 */
function getUserState($chatId, $db) {
    $state = $db->getRow("SELECT * FROM user_states WHERE chat_id = ?", [$chatId]);
    
    if (!$state) {
        return [
            'state' => 'none',
            'data' => []
        ];
    }
    
    return [
        'state' => $state['state'],
        'data' => json_decode($state['data'], true) ?? []
    ];
}

/**
 * 保存用户状态
 * 
 * @param int $chatId 聊天ID
 * @param string $state 状态
 * @param array $data 数据
 * @param object $db 数据库对象
 * @return bool 是否成功
 */
function saveUserState($chatId, $state, $data, $db) {
    $existingState = $db->getRow("SELECT * FROM user_states WHERE chat_id = ?", [$chatId]);
    
    if ($existingState) {
        return $db->update('user_states', [
            'state' => $state,
            'data' => json_encode($data),
            'updated_at' => date('Y-m-d H:i:s')
        ], 'chat_id = ?', [$chatId]) !== false;
    } else {
        return $db->insert('user_states', [
            'chat_id' => $chatId,
            'state' => $state,
            'data' => json_encode($data),
            'created_at' => date('Y-m-d H:i:s'),
            'updated_at' => date('Y-m-d H:i:s')
        ]) !== false;
    }
}

/**
 * 处理充值
 * 
 * @param int $chatId 聊天ID
 * @param int $userId 用户ID
 * @param float $amount 金额
 * @param object $db 数据库对象
 * @param object $bot TelegramBot对象
 * @return void
 */
function handleRecharge($chatId, $userId, $amount, $db, $bot) {
    // 生成订单号
    $orderNumber = 'R' . date('YmdHis') . rand(1000, 9999);
    
    // 计算支付金额（可以添加手续费等）
    $paymentAmount = $amount;
    
    // 创建订单
    $orderId = $db->insert('orders', [
        'user_id' => $userId,
        'order_number' => $orderNumber,
        'type' => 'recharge',
        'amount' => $amount,
        'payment_amount' => $paymentAmount,
        'status' => 'pending',
        'created_at' => date('Y-m-d H:i:s'),
        'updated_at' => date('Y-m-d H:i:s'),
        'expire_at' => date('Y-m-d H:i:s', strtotime('+30 minutes'))
    ]);
    
    if (!$orderId) {
        $bot->sendMessage($chatId, "创建订单失败，请重试。");
        return;
    }
    
    // 构建消息
    $message = "<b>充值订单</b>\n\n";
    $message .= "订单号: {$orderNumber}\n";
    $message .= "金额: {$amount} USDT\n";
    $message .= "状态: 待支付\n";
    $message .= "过期时间: " . date('Y-m-d H:i:s', strtotime('+30 minutes')) . "\n\n";
    
    $message .= "<b>支付方式:</b>\n";
    $message .= "请转账 <b>{$paymentAmount} USDT</b> 到以下地址:\n";
    $message .= "<code>" . USDT_USDT_USDT_USDT_USDT_WALLET_ADDRESS . "</code>\n";
    $message .= "网络: TRC20\n\n";
    
    $message .= "完成支付后，请点击下方按钮查询订单状态。";
    
    // 构建按钮
    $buttons = [
        [
            ['text' => '🔍 查询支付状态', 'callback_data' => "check_payment_{$orderId}"]
        ],
        [
            ['text' => '❌ 取消订单', 'callback_data' => "cancel_order_{$orderId}"]
        ]
    ];
    
    $keyboard = $bot->createInlineKeyboard($buttons);
    
    // 发送消息
    $sentMessage = $bot->sendMessage($chatId, $message, $keyboard);
    
    // 如果发送成功，保存消息ID
    if ($sentMessage['ok'] && isset($sentMessage['result']['message_id'])) {
        $db->update('orders', [
            'message_id' => $sentMessage['result']['message_id'],
            'updated_at' => date('Y-m-d H:i:s')
        ], 'id = ?', [$orderId]);
    }
}

/**
 * 处理赠送会员
 * 
 * @param int $chatId 聊天ID
 * @param int $userId 用户ID
 * @param float $balance 用户余额
 * @param array $plan 会员套餐
 * @param string $targetUsername 目标用户名
 * @param object $db 数据库对象
 * @param object $bot TelegramBot对象
 * @return void
 */
function handleGiftMembership($chatId, $userId, $balance, $plan, $targetUsername, $db, $bot) {
    // 生成订单号
    $orderNumber = 'G' . date('YmdHis') . rand(1000, 9999);
    
    // 计算支付金额
    $paymentAmount = $plan['price_usdt'];
    
    // 创建订单
    $orderId = $db->insert('orders', [
        'user_id' => $userId,
        'order_number' => $orderNumber,
        'type' => 'gift_membership',
        'amount' => $plan['price_usdt'],
        'payment_amount' => $paymentAmount,
        'status' => 'pending',
        'created_at' => date('Y-m-d H:i:s'),
        'updated_at' => date('Y-m-d H:i:s'),
        'expire_at' => date('Y-m-d H:i:s', strtotime('+30 minutes')),
        'gift_username' => $targetUsername,
        'plan_id' => $plan['plan_id']
    ]);
    
    if (!$orderId) {
        $bot->sendMessage($chatId, "创建订单失败，请重试。");
        return;
    }
    
    // 构建消息
    $message = "<b>赠送会员订单</b>\n\n";
    $message .= "订单号: {$orderNumber}\n";
    $message .= "会员套餐: {$plan['name']}\n";
    $message .= "金额: {$plan['price_usdt']} USDT\n";
    $message .= "赠送给: @{$targetUsername}\n";
    $message .= "状态: 待支付\n";
    $message .= "过期时间: " . date('Y-m-d H:i:s', strtotime('+30 minutes')) . "\n\n";
    
    // 构建按钮
    $buttons = [];
    
    // 检查用户余额是否足够
    if (floatval($balance) >= floatval($plan['price_usdt'])) {
        // 余额足够，显示使用余额支付按钮
        $buttons[] = [
            ['text' => '💰 使用余额支付', 'callback_data' => "pay_balance_{$orderId}"]
        ];
        $message .= "您的余额: {$balance} USDT (余额充足)\n\n";
    } else {
        // 余额不足，显示去充值按钮
        $buttons[] = [
            ['text' => '💰 去充值余额', 'callback_data' => "recharge"]
        ];
        $message .= "您的余额: {$balance} USDT (余额不足)\n\n";
        
        $message .= "<b>支付方式:</b>\n";
        $message .= "请转账 <b>{$paymentAmount} USDT</b> 到以下地址:\n";
        $message .= "<code>" . USDT_USDT_USDT_USDT_USDT_WALLET_ADDRESS . "</code>\n";
        $message .= "网络: TRC20\n\n";
        
        $message .= "完成支付后，请点击下方按钮查询订单状态。";
    }
    
    $buttons[] = [
        ['text' => '🔍 查询支付状态', 'callback_data' => "check_payment_{$orderId}"]
    ];
    $buttons[] = [
        ['text' => '❌ 取消订单', 'callback_data' => "cancel_order_{$orderId}"]
    ];
    
    $keyboard = $bot->createInlineKeyboard($buttons);
    
    // 发送消息
    $bot->sendMessage($chatId, $message, $keyboard);
}

/**
 * 显示我的订单
 * 
 * @param int $chatId 聊天ID
 * @param int $userId 用户ID
 * @param object $db 数据库对象
 * @param object $bot TelegramBot对象
 * @return void
 */
function showMyOrders($chatId, $userId, $db, $bot) {
    // 获取最近10个订单
    $orders = $db->getRows("
        SELECT * FROM orders 
        WHERE user_id = ? 
        ORDER BY created_at DESC 
        LIMIT 10
    ", [$userId]);
    
    if (empty($orders)) {
        $bot->sendMessage($chatId, "您还没有任何订单记录。");
        return;
    }
    
    // 构建消息
    $message = "<b>我的订单</b>\n\n";
    
    foreach ($orders as $order) {
        $statusText = getOrderStatusText($order['status']);
        $typeText = $order['type'] == 'membership' ? '会员' : ($order['type'] == 'gift_membership' ? '赠送会员' : '充值');
        
        $message .= "订单号: {$order['order_number']}\n";
        $message .= "类型: {$typeText}\n";
        $message .= "金额: {$order['amount']} USDT\n";
        $message .= "状态: {$statusText}\n";
        $message .= "创建时间: " . date('Y-m-d H:i:s', strtotime($order['created_at'])) . "\n";
        
        if ($order['status'] === 'pending') {
            $message .= "过期时间: " . date('Y-m-d H:i:s', strtotime($order['expire_at'])) . "\n";
            $message .= "支付金额: {$order['payment_amount']} USDT\n";
        }
        
        $message .= "\n";
    }
    
    // 发送消息
    $bot->sendMessage($chatId, $message);
}

/**
 * 显示用户个人资料
 * 
 * @param int $chatId 聊天ID
 * @param int $userId 用户ID
 * @param object $db 数据库对象
 * @param object $bot TelegramBot对象
 * @return void
 */
function showUserProfile($chatId, $userId, $db, $bot) {
    // 获取用户信息
    $user = $db->getRow("SELECT * FROM users WHERE id = ?", [$userId]);
    
    if (!$user) {
        $bot->sendMessage($chatId, "获取用户信息失败，请重试。");
        return;
    }
    
    // 构建消息
    $message = "<b>个人信息</b>\n";
    $message .= "=============\n";
    $message .= "ID: {$user['telegram_id']}\n";
    $message .= "用户名: " . ($user['username'] ? '@' . $user['username'] : '未设置') . "\n";
    $message .= "余额: {$user['balance']} USDT\n";
    
    // 获取订单数量
    $orderCount = $db->getRow("SELECT COUNT(*) as count FROM orders WHERE user_id = ?", [$userId])['count'] ?? 0;
    $message .= "累计下单: {$orderCount} 单\n";
    
    // 检查会员状态
    if ($user['is_premium']) {
        $message .= "会员状态: 已开通\n";
        $message .= "到期时间: " . date('Y-m-d', strtotime($user['premium_expire_date'])) . "\n";
    } else {
        $message .= "会员状态: 未开通\n";
    }
    
    // 发送消息
    $bot->sendMessage($chatId, $message);
}

/**
 * 获取订单状态文本
 * 
 * @param string $status 状态
 * @return string 状态文本
 */
function getOrderStatusText($status) {
    switch ($status) {
        case 'pending':
            return '待支付';
        case 'paid':
            return '已支付';
        case 'cancelled':
            return '已取消';
        case 'completed':
            return '已完成';
        case 'expired':
            return '已过期';
        case 'processing_gift':
            return '处理中';
        case 'failed_gifting':
            return '激活失败';
        default:
            return '未知状态';
    }
}
